diff --git a/DI/XDIHelperExtension.cs b/DI/XDIHelperExtension.cs
index d7a041f..e5b4646 100644
--- a/DI/XDIHelperExtension.cs
+++ b/DI/XDIHelperExtension.cs
@@ -3,14 +3,16 @@ using Microsoft.Extensions.DependencyInjection;
using xCommons.Extensions;
using xExceptions.Constants;
using xFileService.Interfaces;
+using xFileService.Interfaces.Entities;
using xFileService.Providers;
+using xStorageService.Interfaces;
namespace xFileService.DI
{
public static class XDIHelperExtension
{
///
- /// Register Module Provided Service on DI
+ /// Register Service ...
///
///
///
@@ -43,7 +45,7 @@ namespace xFileService.DI
}
///
- /// Register Push Service ...
+ /// Register Service ...
///
///
///
@@ -76,14 +78,26 @@ namespace xFileService.DI
}
//
- // Check String Repository Exists ...
+ // Check Dependencies Exists ...
+ var isDependenciesPassed = !services
+ .GetRegisteredService()
+ .IsNull();
+ if (!isDependenciesPassed)
+ {
+ //
+ Log("AddFileService failed due Dependencies Issues, IXStorageProvider not provided ...");
+ throw exception;
+ }
+
+ //
+ // Check Repository Exists ...
var isRepositoryExists = !services
- .GetRegisteredService()
+ .GetRegisteredService()
.IsNull();
if (!isRepositoryExists)
{
//
- Log("AddFileService failed, IXTagRepository not provided ...");
+ Log("AddFileService failed, IXFileRepository not provided ...");
throw exception;
}
@@ -96,8 +110,4 @@ namespace xFileService.DI
}
#endregion
}
-
- internal class IXTagRepository
- {
- }
}
\ No newline at end of file